"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const build_kit_1 = require("@genesislcap/build-kit");
const consola_1 = tslib_1.__importDefault(require("consola"));
exports.default = (ctx) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { dirs: { cwd }, cli: { isDev, isBuild, options }, config: { clean, copyAssets }, enable: { apiExtractor, cemAnalyzer }, } = ctx;
    if (clean) {
        yield (0, build_kit_1.rm)(['dist', 'tsconfig.tsbuildinfo']);
    }
    if (Array.isArray(copyAssets)) {
        const copyfiles = yield (0, build_kit_1.resolveBin)('copyfiles');
        copyAssets.forEach((glob) => {
            (0, build_kit_1.run)(cwd, `${copyfiles} --verbose --up 1 src/${glob} ./dist/esm`);
        });
    }
    const tsc = yield (0, build_kit_1.resolveBin)('tsc', 'typescript');
    if (isDev) {
        // build a composite project in the working directory in watch mode
        (0, build_kit_1.run)(cwd, `${tsc} -b ./tsconfig.json --verbose -w`);
        return;
    }
    else if (isBuild) {
        // build a composite project in the working directory
        (0, build_kit_1.run)(cwd, `${tsc} -b ./tsconfig.json --verbose`);
        if (apiExtractor) {
            consola_1.default.log('\n@microsoft/api-extractor configuration detected');
            const extractor = yield (0, build_kit_1.resolveBin)('api-extractor', '@microsoft/api-extractor');
            (0, build_kit_1.run)(cwd, `${extractor} run`);
            const documenter = yield (0, build_kit_1.resolveBin)('api-documenter', '@microsoft/api-documenter');
            (0, build_kit_1.run)(cwd, `${documenter} markdown -i dist -o docs/api`);
        }
        if (cemAnalyzer) {
            consola_1.default.log('\n@custom-elements-manifest/analyzer configuration detected');
            const cem = yield (0, build_kit_1.resolveBin)('cem', '@custom-elements-manifest/analyzer');
            (0, build_kit_1.run)(cwd, `${cem} analyze --config custom-elements-manifest.config.*js`);
        }
    }
    else {
        throw new Error(`Unrecognized command: ${JSON.stringify(options)}`);
    }
});
